@@ -10,6 +10,7 @@ from cookiecutter.main import cookiecutter
 
 def _run(project):
     logging.debug("[New] _run")
+    logging.debug(project.args)
     if project.args.template:
         logging.debug("- using template [{0}]".format(project.args.template))
         dn = os.path.abspath(os.path.dirname(os.path.realpath(__file__)) + "/../templates/" + project.args.template)
@@ -53,6 +54,9 @@ def _run(project):
                 if 'mono' in project.options['godot']:
                     ec['godot_mono'] = project.options['godot'].get('mono')
 
+        if (project.args.godot_version):
+            ec['godot_version'] = project.args.godot_version
+
         logging.debug(ec)
         cookiecutter(dn, no_input=True, extra_context=ec)
         logging.log(99, "new project {0} created".format(project.args.name))
@@ -81,6 +85,13 @@ class New:
             default="default"
         )
 
+        cmd.add_argument(
+            "-gv",
+            "--godot-version",
+            dest="godot_version",
+            help="spcify godot version"
+        )
+
         cmd.add_argument(
             "name",
             help="the name of the new project",
