@@ -81,21 +81,23 @@ def _validate(project):
     if 'godot' not in project:
         raise Exception("Project Configuration is Missing [godot] Attribute")
 
-    if 'version' in project.godot:
-        if Version('{0}'.format(project.godot.version)) > Version('3.2.3'):
-            raise Exception('Godot Version {0} is not supported.'.format(project.godot.version))
+    if 'version' not in project.godot:
+        project.godot.local = '3.2.3'
 
-    # backwards compatibility for old location yoption
+    # backwards compatibility for old 'location' option
     if 'location' in project.godot:
         project.godot.local = project.godot.location
 
     if 'local' not in project.godot:
 
-        project.godot.location = ""
+        project.godot.location = ''
 
         if 'arch' not in project.godot:
             project.godot.arch = 64
 
+        if 'release' not in project.godot:
+            project.godot.release = ''
+
         if 'mono' not in project.godot:
             project.godot.mono = False
 
