@@ -306,4 +306,15 @@ godot_versions = {
     ':3.3:rc6:linux:64:mono'        : 'https://downloads.tuxfamily.org/godotengine/3.3/rc6/mono/Godot_v3.3-rc6_mono_x11_64.zip',
     ':3.3:rc6:windows:64:mono'      : 'https://downloads.tuxfamily.org/godotengine/3.3/rc6/mono/Godot_v3.3-rc6_mono_win32.zip',
     ':3.3:rc6:windows:32:mono'      : 'https://downloads.tuxfamily.org/godotengine/3.3/rc6/mono/Godot_v3.3-rc6_mono_win64.zip',
+# 3.3 rc7
+    ':3.3:rc7:darwin::'             : 'https://downloads.tuxfamily.org/godotengine/3.3/rc7/Godot_v3.3-rc7_osx.universal.zip',
+    ':3.3:rc7:linux:32:'            : 'https://downloads.tuxfamily.org/godotengine/3.3/rc7/Godot_v3.3-rc7_x11.32.zip',
+    ':3.3:rc7:linux:64:'            : 'https://downloads.tuxfamily.org/godotengine/3.3/rc7/Godot_v3.3-rc7_x11.64.zip',
+    ':3.3:rc7:windows:64:'          : 'https://downloads.tuxfamily.org/godotengine/3.3/rc7/Godot_v3.3-rc7_win64.exe.zip',
+    ':3.3:rc7:windows:32:'          : 'https://downloads.tuxfamily.org/godotengine/3.3/rc7/Godot_v3.3-rc7_win32.exe.zip',
+    ':3.3:rc7:darwin::mono'         : 'https://downloads.tuxfamily.org/godotengine/3.3/rc7/mono/Godot_v3.3-rc7_mono_osx.64.zip',
+    ':3.3:rc7:linux:32:mono'        : 'https://downloads.tuxfamily.org/godotengine/3.3/rc7/mono/Godot_v3.3-rc7_mono_x11_32.zip',
+    ':3.3:rc7:linux:64:mono'        : 'https://downloads.tuxfamily.org/godotengine/3.3/rc7/mono/Godot_v3.3-rc7_mono_x11_64.zip',
+    ':3.3:rc7:windows:64:mono'      : 'https://downloads.tuxfamily.org/godotengine/3.3/rc7/mono/Godot_v3.3-rc7_mono_win32.zip',
+    ':3.3:rc7:windows:32:mono'      : 'https://downloads.tuxfamily.org/godotengine/3.3/rc7/mono/Godot_v3.3-rc7_mono_win64.zip',
 }
